<?php
/*
 * Plugin Name: WooCommerce PDF Watermark
 * Version: 1.5.1
 * Plugin URI: http://www.woocommerce.com/products/woocommerce-pdf-watermark/
 * Description: Apply text or image-based watermarks to your WooCommerce PDF downloads.
 * Author: WooCommerce
 * Author URI: http://www.woocommerce.com/
 * Developer: Gerhard Potgieter
 * Developer URI: http://gerhardpotgieter.com/
 * Text Domain: woocommerce-pdf-watermark
 * Domain Path: /languages
 * Requires at least: 4.0
 * Tested up to: 6.1
 * WC tested up to: 7.3
 * WC requires at least: 2.6
 * Woo: 754721:20525aa5a4ac479d9dbe0d78a8dce5f4
 *
 * Copyright: 2015-2017 WooCommerce.
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 * @package WooCommerce
 * @author Gerhard Potgieter
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Required functions.
 */
if ( ! function_exists( 'woothemes_queue_update' ) ) {
	require_once( 'woo-includes/woo-functions.php' );
}

/**
 * Plugin updates.
 */
woothemes_queue_update( plugin_basename( __FILE__ ), '20525aa5a4ac479d9dbe0d78a8dce5f4', '754721' );




/**
 * Get since instance of WC_PDF_Watermark class
 *
 * @return object WC_PDF_Watermark
 */
function woocommerce_pdf_watermark() {
	require_once( 'includes/class-wc-pdf-watermark.php' );

	if ( ! defined( 'WC_PDF_WATERMARK_VERSION' ) ) {
			define( 'WC_PDF_WATERMARK_VERSION', '1.3.0' );
	}

	return WC_PDF_Watermark::instance( __FILE__, WC_PDF_WATERMARK_VERSION );
}

if ( is_woocommerce_active() ) {
	woocommerce_pdf_watermark();
}

/**
 * Function wcpdf_remove_folder
 */
function wcpdf_remove_folder( $file_path = 'watermark-tmp') {
	$file_path = ('' != $file_path) ? $file_path : 'watermark-tmp';
	$upload = wp_upload_dir();
	$upload_dir = $upload['basedir'];
	$dest = $upload_dir . '/' . $file_path . '/';
	
	if ( is_dir( $dest ) ) {
		$files = scandir($dest); //get all file names
		$files = array_diff($files, array('.', '..'));
		
		if(0 < count($files)){
			foreach ($files as $file) {
				$lastModifiedTime = filemtime($dest . '/' . $file);
				$currentTime = time();
				$timeDiff = abs($currentTime - $lastModifiedTime)/( 60*60 ); //in hours
				
				if (24 < $timeDiff) {
					if (is_dir($dest . '/' . $file)) {
						unlink($dest . '/' . $file);
						rmdir($dest . '/' . $file);
						array_map('unlink', glob("$file_path/$file/*.*"));
						wcpdf_remove_folder($file_path . '/' . $file);
					} else {
						unlink($dest . '/' . $file);
					}
				}
			}
		}
	}
}
wcpdf_remove_folder();
add_action( 'wcpdf_remove_folder', 'wcpdf_remove_folder' );


/**
 * Function uninstall_watermark_service_plugin.
*/
function uninstall_watermark_service_plugin() {
	$timestamp = wp_next_scheduled( 'wcpdf_remove_folder' );
	wp_unschedule_event( $timestamp, 'wcpdf_remove_folder' );
	wp_clear_scheduled_hook( 'wcpdf_remove_folder' );
}

/**
 * Function install_watermark_service_plugin.
*/
function install_watermark_service_plugin() {
	wp_schedule_event(strtotime('01:00:00'), 'daily', 'wcpdf_remove_folder');
}

/**
 * Run the install scripts upon plugin activation
*/
register_activation_hook( __FILE__, 'install_watermark_service_plugin' );

/*
 run the install scripts upon plugin activation 
*/
register_deactivation_hook( __FILE__, 'uninstall_watermark_service_plugin' );
